@@ -61,9 +61,8 @@ class DataFrameSummary(object):
 
         raise KeyError(column)
     @classmethod
-    def _get_pairplot(self,data=None,continuous=[],categorical=[]):
-        self.df=data
-        print("Hello!",continuous)
+    def _get_pairplot(self,continuous=[],categorical=[]):
+        print("Hello!",self.df)
         if(self.df==None):
             return "Send the Data Please"
         for i in self.df.columns:
